@@ -76,24 +76,18 @@ namespace sharp {
     boost::split(split, source, boost::is_any_of(delimiters));
   }
 
-  void ustring_split(std::vector<Glib::ustring> & split, const Glib::ustring & source,
-                    const char * delimiters)
-  {
-    boost::split(split, source, boost::is_any_of(delimiters));
-  }
-
-  Glib::ustring string_substring(const Glib::ustring & source, int start)
+  std::string string_substring(const std::string & source, int start)
   {
     DBG_ASSERT(start >= 0, "start can't be negative");
     if(source.size() <= (unsigned int)start) {
       return "";
     }
-    return Glib::ustring(source, start, std::string::npos);
+    return std::string(source.begin() + start, source.end());
   }
 
-  Glib::ustring string_substring(const Glib::ustring & source, int start, int len)
+  std::string string_substring(const std::string & source, int start, int len)
   {
-    return Glib::ustring(source, start, len);
+    return std::string(source.begin() + start, source.begin() + start + len);
   }
 
   std::string string_trim(const std::string & source)
@@ -106,23 +100,6 @@ namespace sharp {
     return boost::trim_copy_if(source, boost::is_any_of(set_of_char));
   }
 
-  bool string_starts_with(const std::string & source, const std::string & with)
-  {
-    if(source.empty()) {
-      return false;
-    }
-    return boost::starts_with(source, with);
-  }
-
-  bool string_ends_with(const std::string & source, const std::string & with)
-  {
-    if(source.empty()) {
-      return false;
-    }
-    return boost::ends_with(source, with);
-  }
-
-
   bool string_contains(const std::string & source, const std::string &search)
   {
     return string_index_of(source, search) != -1;
@@ -178,9 +155,9 @@ namespace sharp {
   }
 
 
-  Glib::ustring string_to_lower(const Glib::ustring & source)
+  std::string string_to_lower(const std::string & source)
   {
-    return source.lowercase();
+    return boost::to_lower_copy(source);
   }
 
 }
