@@ -56,8 +56,6 @@ namespace sharp {
 
   void string_split(std::vector<std::string> & split, const std::string & source,
                     const char * delimiters);
-  void ustring_split(std::vector<Glib::ustring> & split, const Glib::ustring & source,
-                    const char * delimiters);
 
   /** copy the substring for %source, starting at %start until the end */
   std::string string_substring(const std::string & source, int start);
@@ -67,8 +65,6 @@ namespace sharp {
   std::string string_trim(const std::string & source);
   std::string string_trim(const std::string & source, const char * set_of_char);
 
-  bool string_starts_with(const std::string & source, const std::string & with);
-  bool string_ends_with(const std::string & source, const std::string & with);
   bool string_contains(const std::string & source, const std::string &);
   int string_index_of(const std::string & source, const std::string & with);
   int string_index_of(const std::string & source, const std::string & with, int);
